#
# spec file for package gnome-contacts
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define eds_version 3.42
%define folks_version 0.14
%define glib_version 2.64

Name:           gnome-contacts
Version:        47.1.1
Release:        1.3
Summary:        Contacts Manager for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
URL:            https://wiki.gnome.org/Apps/Contacts
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  meson >= 0.50
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.56.11
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(folks) >= %{folks_version}
BuildRequires:  pkgconfig(folks-eds) >= %{folks_version}
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(geocode-glib-1.0) >= 3.15.3
BuildRequires:  pkgconfig(gio-unix-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(glib-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(gmodule-export-2.0) >= %{glib_version}
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gtk4) >= 4.12
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.alpha
BuildRequires:  pkgconfig(libebook-1.2) >= %{eds_version}
BuildRequires:  pkgconfig(libedataserver-1.2) >= %{eds_version}
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(libportal-gtk4) >= 0.6
BuildRequires:  pkgconfig(libqrencode) >= 4.1.1

%description
The integraded address book for GNOME.

Among its features are:

 * Search for and view contacts;
 * Edit contact details and make new contacts;
 * Integration with online address books;
 * Automatic linking of contacts from different online sources.

%package -n gnome-shell-search-provider-contacts
Summary:        Contacts Manager for GNOME -- Search Provider for GNOME Shell
Group:          Productivity/Office/Other
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    (%{name} and gnome-shell)

%description -n gnome-shell-search-provider-contacts
The integraded address book for GNOME.

Among its features are:

 * Search for and view contacts;
 * Edit contact details and make new contacts;
 * Integration with online address books;
 * Automatic linking of contacts from different online sources.

This package contains a search provider to enable GNOME Shell to get
search results from contacts.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Dmanpage=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%doc README.md
%{_mandir}/man1/gnome-contacts.1%{ext_man}
%{_bindir}/gnome-contacts
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.gnome.Contacts.appdata.xml
%{_datadir}/applications/org.gnome.Contacts.desktop
%{_datadir}/dbus-1/services/org.gnome.Contacts.service
%{_datadir}/glib-2.0/schemas/org.gnome.Contacts.gschema.xml
%{_datadir}/icons/hicolor/*/*/org.gnome.Contacts*
%dir %{_libexecdir}/gnome-contacts
%{_libexecdir}/gnome-contacts/gnome-contacts-parser

%files -n gnome-shell-search-provider-contacts
%{_datadir}/dbus-1/services/org.gnome.Contacts.SearchProvider.service
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Contacts.search-provider.ini
%{_libexecdir}/gnome-contacts-search-provider

%files lang -f %{name}.lang

%changelog
* Sun Dec 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1.1:
  + Fixed the problem of the "Cancel" button no longer working in
    certain cases (for example when editing a contact).
  + The app name is again properly passed on to the system, fixing
    an issue where it wouldn't show up properly on some systems.
  + On some systems, taking a picture with the camera didn't work
    if graphics drivers aren't installed. This is now fixed.
* Tue Sep 17 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + It's now again possible to take a picture with the camera when
    setting the avatar
  + The UI has been updated to follow the latest GNOME platform
    designs with libadwaita 1.6
  + Several updates to the QR code export dialog now makes sure it
    fits all screen sizes and solves some papercuts
  + You can now cancel a selection with the Escape key
  + A crash during the initial setup window has been fixed
  + Updated translations.
- Add pkgconfig(gstreamer-1.0) BuildRequires: New dependency.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + It's now possible to import multiple VCard files at once.
  + When importing new contacts, the confirmation dialog will also
    helpfully preview the names of the contacts to import.
  + Searching contacts just got a bit faster, with improved
    performance and reduces power consumption, especially on large
    contact lists.
  + Searching for a contact through GNOME Shell and clicking it
    while editing an existing one could lead to a broken state.
    Now, Contacts will first confirm whether it's okay to stop
    editing.
  + A bug where (un)selecting a contact would fail when clicking
    the checkbox directly is now fixed.
  + Phone numbers are now always shown from left to right,
    regardless of the configured text direction.
  + Updated translations.
* Wed Feb 28 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Phone numbers are shown from left to right, regardless of the
    configured text direction.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + It's now possible to import multiple VCard files at once.
  + When importing new contacts, the confirmation dialog will also
    helpfully preview the names of the contacts to import.
  + Searching for a contact through GNOME Shell and clicking it
    while editing an existing one could lead to a broken state.
    Now, Contacts will first confirm whether it's okay to stop
    editing.
  + A bug where (un)selecting a contact would fail when clicking
    the checkbox directly is now fixed.
  + The nightly Flatpak should now properly show avatars for
    contacts.
  + Some outdated and missing info was added in the app
    description.
  + Updated translations.
- Convert to source service for easier updating.
* Tue Sep 19 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.0:
  + A new implementation of the contact list should lead to much
    less memory consumption and a small performance increase.
  + Screen readers should now be able to tell which property of a
    contact is currently focused.
  + Several bugs have been fixed when selecting and cropping an
    avatar. Choosing a file should also be much easier now, as the
    file picker will filter image files.
  + Contacts no longer shows a duplicate window when activated from
    a search result.
  + The app will try to resize more intuitively.
  + Updated translations.
- Comment out BuildRequires on pkgconfig(gnome-desktop-3.0) for
  now, just like in the meson.build script.
* Thu Aug 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Several bugs have been fixed when selecting and cropping an
    avatar.
  + Choosing a file should also be much easier now, as the file
    picker will filter image files.
  + A new implementation of the contact list should lead to much
    less memory consumption and a small performance increase
  + Contacts no longer shows a duplicate window when activated from
    a search result
  + The sidebar will resize more intuitively, rather than keeping a
    fixed width
  + Updated translations.
* Sat Mar 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Contacts can now be shared with a QR code, which allows for
    simple and easy way of sharing contact information across
    devices.
  + The main menu now allows you to export all contacts at once.
  + Unsetting and editing an avatar for a contact is now more
    intuitive with dedicated buttons that are overlayed on top of
    the image.
  + Support for TITLE/ORG vCard properties when importing.
  + Fix a bug which made it impossible to add more than one address
    for a contact.
  + Several changes to the UI that makes it more consistent with
    GNOME design guidelines.
  + Birthdays on a leap year will now get a birthday notification
    on February 28 in non-leap years.
  + Added support for multiple keyboard shortcuts.
  + It's now possible to explicitly unset a birthday.
  + A bug where title buttons where shown twice is now fixed.
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Unsetting and editing an avatar for a contact is now a bit more
    intuitive with the dedicated overlayed buttons.
  + Several changes to comply better with the GNOME HIG.
  + Added unit tests will now help us guarantee correctness.
  + We now parse the first TITLE/ORG vCard properties.
  + Fix a bug which made it impossible to add more than one address
    for a contact.
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + The main menu has been renamed to follow the GNOME HIG and now
    contains an action item to export all contacts.
  + Contacts can now be shared with a QR code, which allows for
    simple and easy way of sharing contact information across
    devices.
  + Birthdays on a leap year will now get a birthday notification
    on February 28 in non-leap years.
  + Added support for multiple keyboard shortcuts
  + It's now possible to explicitly unset a birthday
  + Fix a bug where some title buttons where shown twice
  + Updated translations.
- Add pkgconfig(libqrencode) BuildRequires: New dependency.
* Fri Feb 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unneeded nor used pkgconfig(clutter-gtk-1.0) BuildRequires.
* Thu Feb  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + This is the second stable release in the GNOME 43 series, which
    fixes several bugs when updating or editing a contact.
  + Updated translations.
* Fri Sep 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Contacts can now import and export your contacts in the vCard
    format (aka VCF) to or from a file on the system.
  + Changes under the hood to make searching for contacts faster,
    and fixes several issues when editing or adding a contact.
  + On the UI front, Contacts has revamped the widgets when you're
    editing contacts. Several dialogs (like the "About" window)
    have gotten an upgrade and now look consistent with other GNOME
    apps.
  + Configuring your address books has moved to a dedicated spot in
    the new preferences window.
  + Updated translations.
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.rc:
  + Updated screenshots for GNOME 43.
  + A rewrite of the core internals fixes several issues when
    editing or adding a contact.
  + Several performance optimizations when searching for contacts
    in the app.
  + Some strings for importing and exporting contacts were not
    marked as translatable yet.
  + Updated translations.
* Tue Aug  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Contacts can now import and export your contacts in the vCard
    format (aka VCF) to or from a file on the system.
  + The app will now warn you if your system has a configuration
    issue of your primary address book.
  + Updated translations.
- Drop all traces of telepathy support, now dropped upstream
  (remove pkgconfig(folks-telepathy) and pkgconfig(telepathy-glib)
  disabled BuildRequires and stop passing telepathy=false to
  meson).
- Add pkgconfig(libportal) and pkgconfig(libportal-gtk4)
  BuildRequires: New dependencies.
* Tue Mar 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + A fresh new look thanks to a port to GTK 4 and libadwaita,
    along with a new UI design.
  + It is now possible to open up a contact's location with your
    default maps application (provided it supports "maps:" URIs).
  + It is now possible to show and add the organisational role of a
    contact. This is an especially useful feature for corporate
    address books
  + Contacts shows a little reminder when displaying someone's
    contact information if their birthday is today.
  + Updated translations.
* Mon Mar 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Contact properties can be selected, which means you can also
    copy them to paste it elsewhere.
  + It is now possible to show and add the organisational role of a
    contact. This is mostly useful for corporate address books, as
    you can now see what job a colleague is performing.
  + Some paper cuts that got introduced when porting to GTK4 have
    been resolved.
  + Contacts shows a little reminder when displaying someone's
    contact information if their birthday is today.
  + Fixed launching the Online Accounts dialog in GNOME 42.
  + Updated translations.
- Add desktop-file-utils BuildRequires: New dependency.
* Thu Jan 13 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + A fresh new look thanks to a port to GTK 4 and libadwaita,
    along with a new UI design.
  + It is now possible to open up a contact's location with your
    default maps application (provided it supports "maps:" URIs).
  + Fixes to the birthday editor.
  + Updated translations.
- Drop pkgconfig(cheese) and pkgconfig(cheese-gtk4) BuildRequires:
  no longer needed. Stop passing -Dcheese to meson.
- Replace pkgconfig(gtk+-3.0) BuildRequires with pkgconfig(gtk4),
  and pkgconfig(libhandy-1) with pkgconfig(libadwaita-1): changed
  deps for GTK4 port.
- Add pkgconfig(libportal): Requires to securely access the camera.
- Drop pkgconfig(libedataserverui-1.2): no longer needed.
- Drop patches included in upstream sources:
  + 281decd15546987ca1c467e090ea4abf7a4a0a3b.patch
  + 6883d4fa2a1b3803896a5f5737df765d8f6f6f62.patch
  + b92f5a5198d3a52aaf7317ba6d8e86c633e9e18d.patch
  + f89a9af36e4e2f0e92de62b3f6b7dc9ccc2b5ac6.patch
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add check section and run meson_test macro.
- Update options we give to meson to match what upstream currently
  expects.
- Add b92f5a5198d3a52aaf7317ba6d8e86c633e9e18d.patch and
  6883d4fa2a1b3803896a5f5737df765d8f6f6f62.patch: Fix some
  warnings. Patches from upstream master branch.
- Add f89a9af36e4e2f0e92de62b3f6b7dc9ccc2b5ac6.patch and
  281decd15546987ca1c467e090ea4abf7a4a0a3b.patch: setup-window:
  Refine the margins and the minimum size. Patches from upstream
  master branch.
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Long names are wrapped over more lines, which makes them more
    readable, especially in the case of a small screen.
  + Updated translations.
- Update Supplements syntax in sub-package to current standard.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.beta:
  + When adding or updating a contact, Contacts will now scroll the
    list to the newly-made contact.
  + The Contacts title after cancelling selecting now correctly
    shows "Contacts".
  + When opening a contact, a previously entered birthday is now
    shown.
  + We now have a dedicated selection mode button, which makes the
    UX for touchscreen devices much more intuitive.
  + Several small UI improvements, like extra tooltips that follow
    the GNOME HIG.
  + Updated translations.
* Tue Mar 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Mar  8 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.beta:
  + Cancelling selection no longer hides headerbar buttons.
  + Fixed: stop cursor from appearing when viewing a contact.
  + Updated translations.
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Several issues that occurred when editing or adding postal
    addresses are now fixed.
  + Better accessibility when creating a new contact by adding
    support for mnemonics.
  + You can now select a contact by using a long press.
  + The avatar selector now displays properly on smaller screens.
  + Deleting the final contact now properly clears the title bar.
  + Contacts now also remembers if the window was fullscreened.
  + Several style and typography updates.
  + Updated translations.
* Sat Nov  7 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Fix searching for a contact when Contacts hasn't started yet.
  + Fix for an issue where it was impossible to delete an address
    when editing a contact.
  + Get rid of a minor error message when creating a contact.
  + Building Contacts with telepathy integration is fixed.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38:
  + Editing contacts from a Nextcloud account improved.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.2:
  + Fixed: cannot get past the initial setup screen.
- Changes from version 3.37.1:
  + Fix: sometimes the Contacts icon is not shown properly.
  + Fix: sometimes typing 'n' creates a new contact.
  + Virtual keyboard might give adapt for typing a name.
- Replace pkgconfig(libhandy-0.0) BuildRequires with
  pkgconfig(libhandy-1): Follow upstreams changes.
* Fri Jun 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Fixed an issue where typing n had the same as effect as
    alt-Ctrl-n.
  + Fixed an issue where the setup window didn't show an icon.
  + Updated translations.
* Fri Apr 17 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + AddreeBookList: Fix local addressbook isn't set as default
    addressbook.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.36:
  + A few minor fixes.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + When showing a contact, Contacts now provides buttons to
    perform relevant actions.
  + A refreshed UI when creating or editing a contact.
  + The address book window is now adaptive.
- Changes from version 3.35.1:
  + You can now use a "back" gesture on touch devices to go back to
    the contact list when viewing or editing a contact.
  + Contacts now works on even smaller screens.
  + Nightly now show off with a fancy new icon.
  + Updated translations.
- Disable translation-upate-upstream: execution fails.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jan  5 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Make sure Contacts is started when opening a contact from
    another app (like Geary).
  + Updated translations.
* Thu Sep 12 2019 mgorse@suse.com
- Update to version 3.34:
  + Updated translations.
* Wed Sep  4 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Updated the man page.
  + Updated translations.
  + Changes in version 3.33.91:
  + Make the avatars more in line with the other apps in the GNOME
    ecosystem.
  + Fix searching contacts from GNOME Shell returning no results.
  + Add a small description of the --search option.
  + Updated translations.
  + Changes in version 3.33.4:
  + Flatpak: Allow webcam access (and other small fixes).
  + Even better integration with CI.
  + Add mnemonics to the setup window.
  + Updated translations.
  + Changes in version 3.33.1:
  + Added a show-contact application action, so other applications
    can activate Contacts to show a specific contact.
  + Updated translations.
- Drop gnome-contacts-disambiguate_Gtk.HeaderBar.patch: fixed
    upstream.
* Sat Jun 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-contacts-disambiguate_Gtk.HeaderBar.patch: window:
  Disambiguate Gtk.HeaderBar, fix build with new libhandy.
* Wed Apr 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + appdata: Keep the same appstream ID as in 3.30.
  + src: Use format strings when constructing MessageDialogs.
  + Updated translations.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32:
  + A few minor performance optimizations.
  + Solved a bug where the birthday did not change.
  + Fixed a crash when right-clicking in the contact list.
  + Updated translations.
* Thu Feb 21 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Various other libhandy fixes.
  + Updated translations.
* Wed Jan  9 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Small improvements for the "types" of properties ("Home",
    "Work", …). Contacts should now also be able to more easily
    identify untranslated properties from Google Contacts.
  + Some UI tweaks for the primary menu.
  + The appdata file and the desktop file are now validated by CI.
  + Udated translations.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Updated application icon.
  + Dropped the app menu.
  + Added a dependency on libhandy.
  + Fix birthday not being properly saved.
  + Telepathy is now disabled by default.
- Add pkgconfig(libhandy-0.0) BuildRequires: New dependency.
- Disable pkgconfig(folks-telepathy) and pkgconfig(telepathy-glib)
  BuildRequires and pass -Dtelepathy=false to meson, following
  upstreams new default. Start phasing out telepathy support in
  GNOME.
* Tue Dec 11 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Store: remove eds_persona_store_changed().
  + Contacts.Window: "Done" button actively grabs focus.
  + AccountsList: add a little bit more debugging info.
  + Store: add more debug information.
  + ContactSheet: don't duplicate fields when updating.
  + Updated translations.
* Tue Sep 25 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Fixed a crash when right-clicking in the contact list.
  + Fixed a problem where the symbolic icon was used as app icon.
  + Updated translations.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 3.30:
  + Updated translations.
* Tue Aug 28 2018 bjorn.lie@gmail.com
- Update to version 3.29.92:
  + Various features and bug fixes.
  + Updated translations.
* Tue May  8 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Updated translations.
* Fri Apr 13 2018 luc14n0@linuxmail.org
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Favorite contacts, which are shown at the top of the contact
    list.
  + Sort contacts by their first name or surname.
  + Small tweaks to the UI, such as a more welcoming setup screen
    and rounded avatars.
  + Performance improvements to the GNOME Shell search provider.
  + A slightly decreased memory usage.
  + Updated translations.
- Update:
  + URL tag to https://wiki.gnome.org/Apps/Contacts: currently
    the Contacts' web page.
  + Package description to be a bit more verbose.
- Add geocode-glib-1.0 and gmodule-export-2.0 pkgconfig modules
  BuildRequires to avoid implicit dependencies.
- Drop:
  + pkgconfig(champlain-0.12) BuildRequires: it is not a
    requirement anymore.
  + update-desktop-files BuildRequires and its macro: they are no
    longer required.
  + glib2_gsettings_schema_requires macro: it is not used anymore
    since RPM file triggers.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + The titlebar is now updated when a contact's name changes.
  + The window will now remember its size and restore it on the
    next start.
  + Postal addresses are now sorted before notes.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Support for favorite contacts. These contacts will be shown at
    the top of the list.
  + Contacts now allows sorting by both first name and surname.
  + Avatars are now displayed as a circle and are better optimized
    for memory usage.
  + Selection mode can now be started by right-clicking the contact
    list.
  + Updated translations.
* Thu Jan 25 2018 dimstar@opensuse.org
- Update to version 3.27.4:
  + Contacts now has a shortcuts window.
  + Small tweaks to the setup screen.
  + Support --version as command-line argument.
  + Telepathy is no longer a mandatory dependency.
  + Support for maps can be disabled at compile time.
  + Improved the Shell search provider.
  + Updated translations.
- Pass -D maps=true and -D telepathy=true to meson: keep now
  optional maps and telepathy features enabled.
* Thu Jan 25 2018 fezhang@suse.com
- Update to version 3.27.2:
  + ContactEditor: fix annoying const warning.
  + added compare by type to compare_fields.
  + Meson:
  - Flatpak: update the manifest file to use meson.
  - Drop autotools in favor of Meson.
  - Add configure script for meson.
  - make sure cheese is required when told so.
  - allow 'auto' value for `with-cheese`.
  + Bugs fixed: bgo#789921.
  + Updated translations.
- Drop gnome-contacts-nb-translations.patch: Fixed upstream.
* Wed Jan 24 2018 bjorn.lie@gmail.com
- Update to version 3.26.1:
  + Makefile.am: add README.md. Fixes bgo#792768.
  + Updated translations.
- Drop gnome-contacts-nb-translations.patch: Fixed upstream.
* Sun Dec 24 2017 zaitor@opensuse.org
- Add gnome-contacts-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Use autosetup macro.
- Pass with-cheese=true and with-manpage=true to meson, ensure we
  build the feature we want.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26:
  + Fix crash if initial-setup == false (bgo#787450).
  + Updated translations.
* Tue Sep  5 2017 dimstar@opensuse.org
- Update to version 3.25.92.1:
  + Fix the schema: no longer depend on an inexisting enum.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Added support for Flatpak.
  + Contacts can now be built with Meson.
  + Contacts now provides its own proper app icon.
  + Some labels in the contact sheet are now selectable.
  + Bug fixes:
  - Can't save notes in a contact.
  - Bumped minimal version of telepathy-glib, GTK+ and GLib.
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Run spec-cleaner, modernize spec.
- Stop exporting CFLAGS="%%{optflags} -w", not needed anymore,
  either fixed due to meson build, or in vala itself.
- Drop gnome-shell BuildRequires: It was only there for directory
  ownership, and that is no longer needed.
* Fri Jul 21 2017 zaitor@opensuse.org
- Update to version 3.25.4:
  + Contacts now provides its own application icon.
  + Small UI improvements to the avatar chooser dialog.
  + Folks now requires version 11.4 or higher.
  + Migrated away from intltool and libgd.
  + Got rid of a bunch of warnings and critical messsages.
  + Use the locale to translate months.
- Drop obsolete clean section and post(un) handling, following
  macros dropped: glib2_gsettings_schema_post(un) and
  desktop_database_post(un), file-trigger takes care of this now.
- Drop intltool BuildRequires, no longer needed.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Add docbook-xsl-stylesheets, docbook_4 and xsltproc
  BuildRequires and pass --enable-man-pages=yes to configure, build
  manpages.
- Stop packaging AUTHORS ChangeLog COPYING and README, silence
  rpmlint, and they are in the src rpm anyway.
* Wed Sep 21 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Tue May 17 2016 zaitor@opensuse.org
- Update to version 3.20.0 (fate#318572):
  + Updated translations.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
* Fri Feb 26 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Build fixes.
* Thu Feb 25 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Fixed minor bugs.
  + Updated translations.
* Thu Nov 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Avoid crash in search provider.
  + Remove unused libnotify dependency.
  + Updated translations.
- Drop pkgconfig(libnotify) BuildRequires following upstream.
* Wed Sep 23 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Avoid dialogs from the search provider.
  + Fix desktop file category.
  + Support searching by phone number.
  + Updated translations.
* Wed Apr 22 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Bug fixed concerning Maps initialization.
* Thu Apr 16 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Sat Mar 21 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Fix syntax errors in desktop file keywords translations
    (bgo#736791).
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Finished Contacts - Maps integration.
- Add pkgconfig(libedataserverui-1.2) BuildRequires: new
  dependency.
* Tue Jan 27 2015 zaitor@opensuse.org
- Update to version 3.15.4:
  + Added maps view for postal address.
- Add pkgconfig(champlain-0.12), pkgconfig(clutter-gtk-1.0) and
  pkgconfig(geocode-glib-1.0) BuildRequires: New dependencies.
* Tue Nov 11 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Remove unneeded logs in SearchProvider.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Adapt to gnome-shell's new search provider API.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Fixed change address book bug.
* Tue Sep  2 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + AvatarDialog: Fix syntax error, Gtk.Stack has no
    set_current_page().
  + ContactEditor:
  - Ignore empty values for e-mail addresses, etc.
  - ContactEditor: Move string constants from Contact.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Added inline contact creation.
  + Updated Avatar dialog UI.
  + Improved Adwaita dark variant support.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Reworked setup view.
  + Reworked modes toggling (edit-mode, selection-mode).
  + Fixed birthday field bug.
  + Fixed link field bug.
  + Updated dialogs UI.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Sat Mar  1 2014 zaitor@opensuse.org
- Update to version 3.11.91:
  + Improved Linked Accounts dialog.
* Sun Feb 16 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Updated About dialog info.
  + Fixed email types in New Contact dialog.
  + Removed deprecated gtk+ calls.
  + Fixed minor bugs.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Removed presence widget from ContactPane.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10:
  + Fixed shell-search-provider.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Added appdata description for Contacts.
  + Fixed look in RTL languages.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Ported to Gtk.Revealer.
  + Ported to Gtk.MenuButton.
  + Refined avatar size and name aligment.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Reworked UI to use custom titlebars.
  + Reworked select account dialog.
  + Fixed background colors all over.
  + Fixed "Select a Contact" view.
  + Updated to folks 0.9.5.
  + Migrated Contacts.Window to use Gtk+ templates.
  + Show all contacts everytime now.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Updated AddressBook dialog.
  + Updated Setup window.
  + Fixed in-app delete notification bug.
* Thu Jul 11 2013 dimstar@opensuse.org
- Update to version 3.9.4:
  + Bugs fixed: bgo#679108, bgo#688341, bgo#696265, bgo#696272,
    bgo#698831, bgo#698893, bgo#699081, bgo#700729, bgo#700889,
    bgo#700959, bgo#701515, bgo#701535, bgo#702177, bgo#703470.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Fixed "new" button height.
  + Fix webcam dialog shows blank camera.
  + Fix searching when string is empty.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Fixed font color in contacts list.
  + Make changing birthdate work.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Thu Mar 14 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Animate toolbar transition in selection mode.
  + Updated translations.
* Fri Feb 22 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Added selection to contacts list.
  + Showing a contacts subset (main contacts vs all).
- Replace pkgconfig(gee-1.0) with pkgconfig(gee-0.8), following
  upstreams port to libgee 0.8.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Use libgd.
  + New contact pane design.
  + Fix build with new telepathy-glib.
- Add pkgconfig(gobject-introspection-1.0) BuildRequires: new
  dependency.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Keyboard shortcuts for new and help.
  + Add keywords to desktop file for better searching.
  + Updated translations.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Added help menu item.
* Mon Sep 17 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Use the new gstreamer 1.0 based libcheese
  + Always show search entry
  + Updated translations.
- Drop pkgconfig(gstreamer-interfaces-0.10) and
  pkgconfig(gstreamer-0.10) BuildRequires: configure no longer
  checks for gstreamer and relies entirely on cheese for this.
- Drop pkgconfig(gdk-x11-3.0) BuildRequires: no longer needed.
- Add pkgconfig(cheese) BuildRequires: mimic as closely as possible
  what configure does. In our packages this is currently implied
  by requiring cheese-gtk.
* Fri Sep  7 2012 vuntz@opensuse.org
- Create a gnome-shell-search-provider-contacts for the GNOME Shell
  search provider. It will automatically be installed if
  gnome-contacts and gnome-shell are installed.
- Add a gnome-shell BuildRequires for directory ownership.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Port the webcam support to libcheese
  + Upadted translations.
- Note: the port to libcheese does not infer changes in
  BuildRequires, as we already link against cheese and GStreamer.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + EggListBox converted from vala to C.
  + Fix icon for birthdays.
  + Minor notification themeing fixes.
  + Updated translations.
* Mon Jul 30 2012 dimstar@opensuse.org
- Update to version 3.5.4.1:
  + Rebuilding due to 3.5.4 being built with a broken libtool.
  + Bump libfolks dependency to 0.7.3.
* Sat Jul 28 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Use new libfolks API for Google address book system groups.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Ship a search provider for the shell.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Use the new evolution-data-server APIs for addressbook
    configuration.
- Add pkgconfig(cheese-gtk) BuildRequires: new dependency.
* Fri Jun  8 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Make new avatars with webcam.
  + Fetch more contact info from telepathy.
  + Reimplement sidebar without using GtkTreeView.
- Add pkgconfig()-style BuildRequires: gdk-x11-3.0, gstreamer-0.10
  and gstreamer-interfaces-0.10: new dependencies.
* Tue May  1 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Remove non-working reference to setting Avatar in new contact
    dialog.
  + Correct handling of detecting the main group of contacts in
    Google contacts.
  + Detect more facebook URIs.
  + Updated translations.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Updated translations.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Update the call support to work with latest Telepathy/Empathy
  + Allow linking non-primary contacts to each other and not only
    to primary ones
  + Fix crash in linking
  + Show unknown online status as offline
  + Updated translations.
- Add pkgconfig(telepathy-glib) BuildRequires: new dependency
  upstream.
* Mon Feb 20 2012 dimstar@opensuse.org
- Update to version 3.3.90:
  + New app icon
  + Support cropping of new avatars
  + Minor ui tweaks
  + Exit edit mode whe clicking outside edit widget
  + Add "Add to My contacts" button
  + Create google contacts in the "My contacts" group
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Moved custom CSS to Adwaita
  + Make clicking on edit rows work again
  + Remove initial letter column in lists
  + New look for link dialog
  + Hide search by default
  + Show google contacts that are not "My contacts" as as
    non-primary contacts
  + Make notifications animate in/out
  + Fix up minor UI details to better match new mockups
  + Better initial window size
  + Add inline link suggestions
  + Support undo for link/unlink
  + Delete works for more contacts
  + New first run dialog
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Use %%glib2_gsettings_schema_* macros for new GSettings schema.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + Add application menu
  + Support changing the address book
  + Only show primary contacts in the main list except when
    searching
  + Add toolbar in the new gnome 3 style
- Changes from (unreleased) version 3.3.2:
  + Polish details in the UI
  + Work with latest vala master
- Add new pkgconfig(folks-eds) BuildRequires, following upstream
  changes.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.1:
  + New design for the content pane
  + Undo and in-app notifications
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Oct 21 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Fixed crashes
  + Fixed display name for Google contact sources
  + Add Unity to OnlyShowIn
  + Fix up spacing in contact pane
- Add pkgconfig(gee-1.0) BuildRequires: new dependency.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0.1:
  + Fix label for local contacts
  + Fix video calls
- Changes from version 3.2.0:
  + Fix spacing due to GtkGrid API changes
  + Add quit and search keyboard shortcuts
  + Close error dialogs on response
  + Show birthdays with correct timezone
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 0.1.5.2:
  + Make GOA addressbooks default it there is no default
  + Make creating contacts on google work
- Changes from version 0.1.5.1:
  + Fix build issue
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 0.1.5:
  + Support linking and unlinking
  + Support linking suggestions
  + Don't require running evolution to pick up eds addressbooks
- Add new pkgconfig() BuildRequires: glib-2.0, goa-1.0,
  libebook-1.2, libedataserver-1.2. They are new dependencies
  upstream (the glib-2.0 one being now explicit, with a versioned
  dependency).
* Thu Sep  8 2011 vuntz@opensuse.org
- Update to version 0.1.4.1:
  + Fix crash
- Changes from version 0.1.4:
  + Unique application instance support
  + Support browsing for avatar file
  + Support deleting (some) contacts
  + Support linking contacts
  + Support for new fields:
  - nickname
  - birthday (readonly)
  - company/title/etc (readonly)
  + Lots of small UI tweaks
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: new dependency.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 0.1.3:
  + Fix build due to libm missing
  + Lots of UI polish
  + Working contact editing
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 0.1.2:
  + Update to libfolks 0.6.0
  + Allow showing a contact from the commandline
* Fri Jul  1 2011 vuntz@opensuse.org
- Update to version 0.1.1:
  + Lots more work on the UI
  + Initial work on editing
- Add pkgconfig(libnotify) BuildRequires.
- Remove have_desktop_file and have_lang defines now that we have a
  .desktop file and translations.
* Wed Jun 15 2011 vuntz@opensuse.org
- Initial package (version 0.1.0).
